__version__ = "0.11.1"
__version_info__ = ['0', '11', '1']
__version_vcs_info__ = {'branch': 'master',
 'revid': '062e70b',
 'revno': 127,
 'toplevel': '/home/cstavr/okeanos/devflow'}
__version_user_info__ = "cstavr@okeanosdev-91.admin.grnet.gr"
